==> opinion_monitor-7.x-1.3.tar.gz: opinion_monitor/templates/node--opmon_content.tpl.php <==
<?php

//------------------------------------------------------------------------------
// DATA PREPARATION
//------------------------------------------------------------------------------

// Load the Opinion Monitor Question nodes associated with this content.
$opmon_questions = array();
/*
foreach ($field_questions as $opmon_question) {
  $opmon_questions[$opmon_question['nid']] = node_load($opmon_question['nid']);
}
*/
$opmon_questions = field_get_items('node', $node, 'questions');

// Store the Opinion Monitor Content node ID in a handy variable.
$opmon_content_nid = $node->nid;

// Grab the Opinion Monitor node ID from the global variable declared in node-opmon.tpl.php.
global $opmon_id;

//------------------------------------------------------------------------------
// OPINION MONITOR CONTENT NODE
//------------------------------------------------------------------------------

// Output this Opinion Monitor Content node in a DIV of its own.
?>
<div id="node-<?php echo $opmon_content_nid; ?>" class="node-opmon-content node<?php if ($sticky) { echo ' sticky'; } ?><?php if (!$status) { echo ' node-unpublished'; } ?>">
<?php
if ($page == 0) {
?>
  <h3><a href="<?php echo $node_url; ?>" title="<?php echo $title; ?>"><?php echo $title; ?></a></h3>
<?php
}
?>
  <div class="content clear-block">
<?php
// Output the node's content - the actual "Opinion Monitor Content".
echo $body[0]['value'];
?>
  </div>

<?php

//------------------------------------------------------------------------------
// OPINION MONITOR QUESTION NODES
//------------------------------------------------------------------------------

// Check if we have any questions to output.
if(count($opmon_questions) > 0) {
?>
  <div class="opmon-questions-wrapper">
    <form class="opmon-questions-form" id="opmon-questions-form-<?php echo $opmon_content_nid; ?>" action="#" method="post">
      <ol class="opmon-questions">
<?php
  // Output each Opinion Monitor Question node as an element in an ordered list.
  foreach ($opmon_questions as $opmon_question) {
?>
        <li id="opmon-<?php echo $opmon_id; ?>-node-<?php echo $node->nid; ?>-question-<?php echo $opmon_question['nid']; ?>">
          <input type="hidden" class="opmon-answer-slider-field" id="opmon-answer-slider-<?php echo $opmon_id; ?>-<?php echo $opmon_content_nid; ?>-<?php echo $opmon_question['nid']; ?>-field" />
<?php
    // Output the Opinion Monitor Question nodes using Drupal's theme() function.
    echo drupal_render(node_view($opmon_question['node']));
?>
        </li>
<?php
  }
?>
      </ol>
      <div>
        <input class="opmon-form-submit" type="button" value="<?php echo t('Save'); ?>" />
        <p class="opmon-form-response"></p>
      </div>
    </form>
  </div>
<?php
}
?>
</div>

==> opinion_monitor-7.x-1.8.tar.gz: opinion_monitor/templates/node--opmon_content.tpl.php <==
<?php

//------------------------------------------------------------------------------
// DATA PREPARATION
//------------------------------------------------------------------------------

// Load the Opinion Monitor Question nodes associated with this content.
$opmon_questions = array();
$opmon_questions = field_get_items('node', $node, 'questions');

// Store the Opinion Monitor Content node ID in a handy variable.
$opmon_content_nid = $node->nid;

// Grab the Opinion Monitor node ID from the global variable declared in node-opmon.tpl.php.
global $opmon_id;

//------------------------------------------------------------------------------
// OPINION MONITOR CONTENT NODE
//------------------------------------------------------------------------------

// Output this Opinion Monitor Content node in a DIV of its own.
?>
<div id="node-<?php echo $opmon_content_nid; ?>" class="node-opmon-content node<?php if ($sticky) { echo ' sticky'; } ?><?php if (!$status) { echo ' node-unpublished'; } ?>">
<?php
if ($page == 0) {
?>
  <h3><a href="<?php echo $node_url; ?>" title="<?php echo $title; ?>"><?php echo $title; ?></a></h3>
<?php
}
?>
  <div class="content clear-block">
<?php
// Output the node's content - the actual "Opinion Monitor Content".
echo $body[0]['value'];
?>
  </div>

<?php

//------------------------------------------------------------------------------
// OPINION MONITOR QUESTION NODES
//------------------------------------------------------------------------------

// Check if we have any questions to output.
if(count($opmon_questions) > 0) {
?>
  <div class="opmon-questions-wrapper">
    <form class="opmon-questions-form" id="opmon-questions-form-<?php echo $opmon_content_nid; ?>" action="#" method="post">
      <ol class="opmon-questions">
<?php
  // Output each Opinion Monitor Question node as an element in an ordered list.
  foreach ($opmon_questions as $opmon_question) {
?>
        <li id="opmon-<?php echo $opmon_id; ?>-node-<?php echo $node->nid; ?>-question-<?php echo $opmon_question['target_id']; ?>">
          <input type="hidden" class="opmon-answer-slider-field" id="opmon-answer-slider-<?php echo $opmon_id; ?>-<?php echo $opmon_content_nid; ?>-<?php echo $opmon_question['target_id']; ?>-field" />
<?php
    // Output the Opinion Monitor Question nodes using Drupal's theme() function.
    $q_node = node_load($opmon_question['target_id']);
    echo drupal_render(node_view($q_node));
?>
        </li>
<?php
  }
?>
      </ol>
      <div>
        <input class="opmon-form-submit" type="button" value="<?php echo t('Save'); ?>" />
        <p class="opmon-form-response"></p>
      </div>
    </form>
  </div>
<?php
}
?>
</div>
